@@ -103,13 +103,13 @@ class Classifier(nn.Module):
 
     def predict_proba(self, x):
         if self.n_layers == 2:
-            return self.layers["layer2"](self.layers["layer1"](x)).detach().cpu().numpy()
-        return self.layers["layer1"](x).detach().cpu().numpy()
+            return self.layers["layer2"](self.layers["layer1"](x)).detach().float().cpu().numpy()
+        return self.layers["layer1"](x).detach().float().cpu().numpy()
 
     def predict(self, x):
         if self.n_layers == 2:
-            return self.layers["layer2"](self.layers["layer1"](x)).argmax(1).detach().cpu().numpy()
-        return self.layers["layer1"](x).argmax(1).detach().cpu().numpy()
+            return self.layers["layer2"](self.layers["layer1"](x)).argmax(1).detach().float().cpu().numpy()
+        return self.layers["layer1"](x).argmax(1).detach().float().cpu().numpy()
 
 
 class Classifier2(nn.Module):
@@ -157,10 +157,10 @@ class Classifier2(nn.Module):
                     m.bias.data.zero_()
 
     def predict_proba(self, x):
-        return self.layers["layer2"](self.layers["layer1"](x)).detach().cpu().numpy()
+        return self.layers["layer2"](self.layers["layer1"](x)).detach().float().cpu().numpy()
 
     def predict(self, x):
-        return self.layers["layer2"](self.layers["layer1"](x)).argmax(1).detach().cpu().numpy()
+        return self.layers["layer2"](self.layers["layer1"](x)).argmax(1).detach().float().cpu().numpy()
 
 
 class Classifier3(nn.Module):
@@ -201,10 +201,10 @@ class Classifier3(nn.Module):
             #     nn.init.constant_(m.bias, 0.125)
 
     def predict_proba(self, x):
-        return self.linear2(x).detach().cpu().numpy()
+        return self.linear2(x).detach().float().cpu().numpy()
 
     def predict(self, x):
-        return self.linear2(x).argmax(1).detach().cpu().numpy()
+        return self.linear2(x).argmax(1).detach().float().cpu().numpy()
 
 
 class Encoder(nn.Module):
@@ -441,10 +441,10 @@ class SHAPKANAutoEncoder2(nn.Module):
                 nn.init.constant_(m.bias, 0.125)
 
     def predict_proba(self, x):
-        return self.classifier(x).detach().cpu().numpy()
+        return self.classifier(x).detach().float().cpu().numpy()
 
     def predict(self, x):
-        return self.classifier(x).argmax(1).detach().cpu().numpy()
+        return self.classifier(x).argmax(1).detach().float().cpu().numpy()
 
     def _kld(self, z, q_param, h_last=None, p_param=None):
         if len(z.shape) == 1:
@@ -622,10 +622,10 @@ class KANAutoEncoder2(nn.Module):
             #     nn.init.constant_(m.bias, 0.125)
 
     def predict_proba(self, x):
-        return self.classifier(x).detach().cpu().numpy()
+        return self.classifier(x).detach().float().cpu().numpy()
 
     def predict(self, x):
-        return self.classifier(x).argmax(1).detach().cpu().numpy()
+        return self.classifier(x).argmax(1).detach().float().cpu().numpy()
 
     def _kld(self, z, q_param, h_last=None, p_param=None):
         if len(z.shape) == 1:
@@ -802,11 +802,11 @@ class KANAutoEncoder3(nn.Module):
 
     def predict_proba(self, x):
         enc = self.enc(x)
-        return self.classifier(enc).detach().cpu().numpy()
+        return self.classifier(enc).detach().float().cpu().numpy()
 
     def predict(self, x):
         enc = self.enc(x)
-        return self.classifier(enc).argmax(1).detach().cpu().numpy()
+        return self.classifier(enc).argmax(1).detach().float().cpu().numpy()
 
     def _kld(self, z, q_param, h_last=None, p_param=None):
         if len(z.shape) == 1:
